@@ -46,7 +46,7 @@ class Cpython(PythonBuilder):
         yield f"-L{self.deps_lib}"
         if PPG.target.is_linux:
             yield "-Wl,-z,origin"
-            yield f"-Wl,-rpath={self.c_configure_prefix}"
+            yield f"-Wl,-rpath={self.c_configure_prefix}/lib"
 
     def has_configure_opt(self, name, *variants):
         opts = self.c_configure_args_from_config
@@ -146,7 +146,7 @@ class Cpython(PythonBuilder):
                 self.run(bin_python, "-mpip", "install", "-U", lib_name)
 
     def _finalize(self):
-        is_shared = self.setup.prefix or self.has_configure_opt("--enable-shared", "yes")
+        is_shared = self.has_configure_opt("--enable-shared", "yes")
         if is_shared:
             lib_auto_correct = LibAutoCorrect(self.c_configure_prefix, self.install_folder)
             lib_auto_correct.run()
@@ -182,6 +182,14 @@ class Cpython(PythonBuilder):
             LOG.info("Exercising configured validation script: %s" % runez.short(validation_script))
             self.run(bin_python, validation_script)
 
+        check_venvs = PPG.config.get_value("cpython-check-venvs")
+        if check_venvs:
+            if check_venvs in ("venv", "all"):
+                self._check_venv(bin_python)
+
+            if check_venvs in ("copies", "all"):
+                self._check_venv(bin_python, copies=True)
+
         if PPG.config.get_value("cpython-compile-all"):
             self.run(bin_python, "-mcompileall", "-q", self.install_folder / "lib")
 
@@ -199,6 +207,18 @@ class Cpython(PythonBuilder):
 
         PPG.config.cleanup_folder(self, "cpython-clean-2nd-pass", "cpython-clean")
 
+    def _check_venv(self, bin_python, copies=False):
+        """Verify that the freshly compiled python can create venvs without issue"""
+        folder = "venv"
+        args = ["-mvenv"]
+        if copies:
+            args.append("--copies")
+            folder += "-copies"
+
+        folder = self.setup.folders.build_folder / "test-venvs" / folder
+        self.run(bin_python, *args, folder)
+        self.run(bin_python, "-mpip", "--version")
+
     @staticmethod
     def _represented_yaml(bits):
         content = [yaml.safe_dump(runez.serialize.json_sanitized({x: y}), width=140) for x, y in bits]
